'use strict';

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _regenerator = _interopRequireDefault(require("@babel/runtime/regenerator"));

var _asyncToGenerator2 = _interopRequireDefault(require("@babel/runtime/helpers/asyncToGenerator"));

var _fs = _interopRequireDefault(require("fs"));

var _os = _interopRequireDefault(require("os"));

var _path = _interopRequireDefault(require("path"));

var _tmp = _interopRequireDefault(require("tmp"));

var _aesJs = _interopRequireDefault(require("aes-js"));

var _sqlite = _interopRequireDefault(require("sqlite"));

var _ibackuptool = _interopRequireDefault(require("ibackuptool"));

var _inquirer = require("inquirer");

var _terminal = _interopRequireDefault(require("./terminal"));

var _table = require("./table");

_tmp["default"].setGracefulCleanup();

var dir = "/Users/".concat(_os["default"].userInfo().username, "/Library/Application Support/MobileSync/Backup/");
var fields = [{
  name: 'Name',
  key: 'ZNAME'
}, {
  name: 'Model',
  key: 'ZMODEL'
}, {
  name: 'IP',
  key: 'ZLOCALIP'
}, {
  name: 'MAC',
  key: 'ZMAC'
}, {
  name: 'Firmware',
  key: 'ZEXTFWVERSION'
}, {
  name: 'SSID',
  key: 'ZSSID'
}, {
  name: 'Token',
  key: 'ZTOKEN'
}];
var sql = "SELECT ".concat(fields.map(function (_ref) {
  var key = _ref.key;
  return key;
}).join(','), " FROM ZDEVICE");
var formatter = new Intl.DateTimeFormat('en-US', {
  year: 'numeric',
  month: 'short',
  day: 'numeric',
  hour: 'numeric',
  minute: '2-digit',
  hour12: false
});
!(0, _asyncToGenerator2["default"])(
/*#__PURE__*/
_regenerator["default"].mark(function _callee2() {
  var list, _ref4, udid;

  return _regenerator["default"].wrap(function _callee2$(_context2) {
    while (1) {
      switch (_context2.prev = _context2.next) {
        case 0:
          _context2.prev = 0;

          _fs["default"].readdirSync(dir, {
            encoding: 'utf8'
          });

          _context2.next = 12;
          break;

        case 4:
          _context2.prev = 4;
          _context2.t0 = _context2["catch"](0);

          if (!(_context2.t0.code === 'EPERM')) {
            _context2.next = 11;
            break;
          }

          ['It seems your terminal app has no access to the backups folder.', 'To fix this just grant full disk access to the terminal app:', ' → System Preferences → Security & Privacy → "Privacy" tab → select "Full Disk Access"', 'And then click the [+] plus button to add the terminal app.'].forEach(function (str) {
            return _terminal["default"].error(str);
          });
          process.exit(1);
          _context2.next = 12;
          break;

        case 11:
          throw new Error(_context2.t0);

        case 12:
          _context2.next = 14;
          return _ibackuptool["default"].run('backups.list');

        case 14:
          _context2.t1 = function (_ref3) {
            var encrypted = _ref3.encrypted;
            return !encrypted;
          };

          list = _context2.sent.filter(_context2.t1);

          if (list.length === 0) {
            _terminal["default"].info('You have no unencrypted backups');

            process.exit(0);
          }

          _context2.next = 19;
          return (0, _inquirer.prompt)([{
            type: 'list',
            name: 'udid',
            message: 'Choose backup to inspect (only unencrypted backups are displayed):',
            choices: list.map(function (_ref5) {
              var udid = _ref5.udid,
                  deviceName = _ref5.deviceName,
                  date = _ref5.date,
                  iOSVersion = _ref5.iOSVersion;
              return {
                name: "".concat(deviceName, " (iOS ").concat(iOSVersion, " / ").concat(formatter.format(new Date(date)), ")"),
                "short": deviceName,
                value: udid
              };
            })
          }]);

        case 19:
          _ref4 = _context2.sent;
          udid = _ref4.udid;

          _tmp["default"].dir({
            mode: 493
          },
          /*#__PURE__*/
          function () {
            var _ref6 = (0, _asyncToGenerator2["default"])(
            /*#__PURE__*/
            _regenerator["default"].mark(function _callee(err, dir, cleanupCallback) {
              var files;
              return _regenerator["default"].wrap(function _callee$(_context) {
                while (1) {
                  switch (_context.prev = _context.next) {
                    case 0:
                      if (!err) {
                        _context.next = 2;
                        break;
                      }

                      throw err;

                    case 2:
                      _context.next = 4;
                      return _ibackuptool["default"].run('backup.files', {
                        backup: udid,
                        extract: dir,
                        filter: '_mihome'
                      });

                    case 4:
                      files = _context.sent;
                      files = files.filter(function (_ref7) {
                        var path = _ref7.path;
                        return /_mihome/.test(path);
                      });

                      if (!(files.length > 0)) {
                        _context.next = 11;
                        break;
                      }

                      _context.next = 9;
                      return readDB(_path["default"].resolve(dir, files[0].domain, files[0].path));

                    case 9:
                      _context.next = 12;
                      break;

                    case 11:
                      _terminal["default"].info('There is no MiHome database files in the backup');

                    case 12:
                      cleanupCallback();

                    case 13:
                    case "end":
                      return _context.stop();
                  }
                }
              }, _callee);
            }));

            return function (_x, _x2, _x3) {
              return _ref6.apply(this, arguments);
            };
          }());

        case 22:
        case "end":
          return _context2.stop();
      }
    }
  }, _callee2, null, [[0, 4]]);
}))();

function readDB(_x4) {
  return _readDB.apply(this, arguments);
}

function _readDB() {
  _readDB = (0, _asyncToGenerator2["default"])(
  /*#__PURE__*/
  _regenerator["default"].mark(function _callee3(filename) {
    var db, devices, key;
    return _regenerator["default"].wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            _context3.next = 2;
            return _sqlite["default"].open(filename);

          case 2:
            db = _context3.sent;
            _context3.next = 5;
            return db.all(sql);

          case 5:
            devices = _context3.sent;
            key = Array(16).fill(0x0);
            devices.forEach(function (item) {
              if (!item.ZTOKEN || item.ZTOKEN.length !== 96) return;
              var decrypted = new _aesJs["default"].ModeOfOperation.ecb(key).decrypt(_aesJs["default"].utils.hex.toBytes(item.ZTOKEN));
              decrypted = _aesJs["default"].utils.utf8.fromBytes(decrypted).slice(0, 32);
              item.ZTOKEN = "".concat(decrypted, " (decrypted)");
            });
            (0, _table.drawDevices)(devices, fields);

          case 9:
          case "end":
            return _context3.stop();
        }
      }
    }, _callee3);
  }));
  return _readDB.apply(this, arguments);
}